@@ -12,8 +12,8 @@ int f(_Bool x)
    bool_var != 0 is the same as bool_var. */
 /* { dg-final { scan-tree-dump-times "!= 0" 0 "optimized"} } */
 
-/* There should be no adde for powerpc. Checking if we actually optimizated
-   away the comparision.  */
-/* { dg-final { scan-assembler-times "adde" 0 { target powerpc-*-* } } } */
+/* There should be no adde for powerpc.  Check if we actually optimized
+   away the comparison.  */
+/* { dg-final { scan-assembler-times "adde" 0 { target powerpc*-*-* } } } */
 
 /* { dg-final { cleanup-tree-dump "optimized" } } */
