@@ -1,9 +1,9 @@
 // Check if ivars may be accessed via the C++ dot notation.
-
 // { dg-do run }
 // { dg-options "-fno-objc-call-cxx-cdtors" }
+// { dg-xfail-run-if "Needs OBJC2 ABI" { *-*-darwin* && { lp64 && { ! objc2 } } } { "-fnext-runtime" } { "" } } 
 
-#include <objc/Object.h>
+#include "../objc-obj-c++-shared/Object1.h"
 #include <stdlib.h>
 #define CHECK_IF(expr) if(!(expr)) abort()
 
@@ -40,3 +40,4 @@ int main (void)
   [obj manipulate_ivars];
   [obj free];
 }
+#include "../objc-obj-c++-shared/Object1-implementation.h"
